# Task Manager API

A barebones task manager API built with FastAPI and SQLite.

## Features

- Create, read, update, and delete tasks
- SQLite database with Alembic migrations
- RESTful API endpoints
- Health check endpoint
- CORS support
- OpenAPI documentation

## Requirements

- Python 3.8+
- FastAPI
- SQLite

## Installation

1. Install dependencies:
```bash
pip install -r requirements.txt
```

2. Run the application:
```bash
uvicorn main:app --reload
```

The API will be available at `http://localhost:8000`

## API Endpoints

- `GET /` - API information
- `GET /health` - Health check
- `GET /api/v1/tasks/` - List all tasks
- `POST /api/v1/tasks/` - Create a new task
- `GET /api/v1/tasks/{task_id}` - Get a specific task
- `PUT /api/v1/tasks/{task_id}` - Update a task
- `DELETE /api/v1/tasks/{task_id}` - Delete a task

## Documentation

- OpenAPI spec: `http://localhost:8000/openapi.json`
- Swagger UI: `http://localhost:8000/docs`
- ReDoc: `http://localhost:8000/redoc`

## Database

The application uses SQLite with the database file stored at `/app/storage/db/db.sqlite`.
